==> esp32c3-0.3.0.crate: esp32c3-0.3.0/src/apb_ctrl/redcy_sig0.rs <==
#[doc = "Register `REDCY_SIG0` reader"]
pub struct R(crate::R<REDCY_SIG0_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<REDCY_SIG0_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<REDCY_SIG0_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<REDCY_SIG0_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `REDCY_SIG0` writer"]
pub struct W(crate::W<REDCY_SIG0_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<REDCY_SIG0_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<REDCY_SIG0_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<REDCY_SIG0_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `REDCY_SIG0` reader - reg_redcy_sig0"]
pub struct REDCY_SIG0_R(crate::FieldReader<u32, u32>);
impl REDCY_SIG0_R {
    pub(crate) fn new(bits: u32) -> Self {
        REDCY_SIG0_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for REDCY_SIG0_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `REDCY_SIG0` writer - reg_redcy_sig0"]
pub struct REDCY_SIG0_W<'a> {
    w: &'a mut W,
}
impl<'a> REDCY_SIG0_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x7fff_ffff) | (value as u32 & 0x7fff_ffff);
        self.w
    }
}
#[doc = "Field `REDCY_ANDOR` reader - reg_redcy_andor"]
pub struct REDCY_ANDOR_R(crate::FieldReader<bool, bool>);
impl REDCY_ANDOR_R {
    pub(crate) fn new(bits: bool) -> Self {
        REDCY_ANDOR_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for REDCY_ANDOR_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bits 0:30 - reg_redcy_sig0"]
    #[inline(always)]
    pub fn redcy_sig0(&self) -> REDCY_SIG0_R {
        REDCY_SIG0_R::new((self.bits & 0x7fff_ffff) as u32)
    }
    #[doc = "Bit 31 - reg_redcy_andor"]
    #[inline(always)]
    pub fn redcy_andor(&self) -> REDCY_ANDOR_R {
        REDCY_ANDOR_R::new(((self.bits >> 31) & 0x01) != 0)
    }
}
impl W {
    #[doc = "Bits 0:30 - reg_redcy_sig0"]
    #[inline(always)]
    pub fn redcy_sig0(&mut self) -> REDCY_SIG0_W {
        REDCY_SIG0_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "APB_CTRL_REDCY_SIG0_REG\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [redcy_sig0](index.html) module"]
pub struct REDCY_SIG0_SPEC;
impl crate::RegisterSpec for REDCY_SIG0_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [redcy_sig0::R](R) reader structure"]
impl crate::Readable for REDCY_SIG0_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [redcy_sig0::W](W) writer structure"]
impl crate::Writable for REDCY_SIG0_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets REDCY_SIG0 to value 0"]
impl crate::Resettable for REDCY_SIG0_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp32c3-0.4.0.crate: esp32c3-0.4.0/src/apb_ctrl/redcy_sig0.rs <==
#[doc = "Register `REDCY_SIG0` reader"]
pub struct R(crate::R<REDCY_SIG0_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<REDCY_SIG0_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<REDCY_SIG0_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<REDCY_SIG0_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `REDCY_SIG0` writer"]
pub struct W(crate::W<REDCY_SIG0_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<REDCY_SIG0_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<REDCY_SIG0_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<REDCY_SIG0_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `REDCY_SIG0` reader - reg_redcy_sig0"]
pub struct REDCY_SIG0_R(crate::FieldReader<u32, u32>);
impl REDCY_SIG0_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        REDCY_SIG0_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for REDCY_SIG0_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `REDCY_SIG0` writer - reg_redcy_sig0"]
pub struct REDCY_SIG0_W<'a> {
    w: &'a mut W,
}
impl<'a> REDCY_SIG0_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x7fff_ffff) | (value as u32 & 0x7fff_ffff);
        self.w
    }
}
#[doc = "Field `REDCY_ANDOR` reader - reg_redcy_andor"]
pub struct REDCY_ANDOR_R(crate::FieldReader<bool, bool>);
impl REDCY_ANDOR_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        REDCY_ANDOR_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for REDCY_ANDOR_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bits 0:30 - reg_redcy_sig0"]
    #[inline(always)]
    pub fn redcy_sig0(&self) -> REDCY_SIG0_R {
        REDCY_SIG0_R::new((self.bits & 0x7fff_ffff) as u32)
    }
    #[doc = "Bit 31 - reg_redcy_andor"]
    #[inline(always)]
    pub fn redcy_andor(&self) -> REDCY_ANDOR_R {
        REDCY_ANDOR_R::new(((self.bits >> 31) & 1) != 0)
    }
}
impl W {
    #[doc = "Bits 0:30 - reg_redcy_sig0"]
    #[inline(always)]
    pub fn redcy_sig0(&mut self) -> REDCY_SIG0_W {
        REDCY_SIG0_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "APB_CTRL_REDCY_SIG0_REG\n\nThis register you can [`read`]
(crate::generic::Reg::read), [`write_with_zero`]
(crate::generic::Reg::write_with_zero), [`reset`]
(crate::generic::Reg::reset), [`write`]
(crate::generic::Reg::write), [`modify`]
(crate::generic::Reg::modify). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [redcy_sig0]
(index.html) module"]
pub struct REDCY_SIG0_SPEC;
impl crate::RegisterSpec for REDCY_SIG0_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [redcy_sig0::R]
(R) reader structure"]
impl crate::Readable for REDCY_SIG0_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [redcy_sig0::W]
(W) writer structure"]
impl crate::Writable for REDCY_SIG0_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets REDCY_SIG0 to value 0"]
impl crate::Resettable for REDCY_SIG0_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
